@@ -1586,9 +1586,7 @@ void AAptInterface::startFetchDates()
 	iDateRequestsReceived = 0;
 	iNetworkError = QNetworkReply::NoError;
 
-	QString dbgcount = QString("need to fetch date for %1 packages").arg(fetchable.count());
-	qDebug() << dbgcount;
-	logToFile(dbgcount);
+	qDebug() << "package dates to fetch:" << fetchable.count();
 
 	QHashIterator<QString, Package*> fe( fetchable );
 	while (fe.hasNext() && !iTerminated)
@@ -1639,7 +1637,6 @@ void AAptInterface::startFetchDates()
 					iNetworkError != QNetworkReply::QNetworkReply::ContentAccessDenied && iNetworkError != QNetworkReply::QNetworkReply::ContentNotFoundError )
 				{
 					qDebug() << "fatal network error, aborting fetch";
-					logToFile(QString("Fatal network error, date fetch aborted"));
 					break;
 				} else {
 					nam->head(r);
@@ -1683,10 +1680,8 @@ void AAptInterface::startFetchDates()
 		QApplication::processEvents();
 	}
 
-	QString dbgstr = QString("sent %1 requests, received %2 replies with %3 errors").arg(iDateRequestsSent).arg(iDateRequestsReceived).arg(iDateRequestErrors);
-
-	qDebug() << dbgstr;
-	logToFile(dbgstr);
+	qDebug() << "sent" << iDateRequestsSent << "requests, received" << iDateRequestsReceived << "replies with"
+			<< iDateRequestErrors << "errors";
 
 	logToFile( QString("Finished fetching package dates") );
 
@@ -1731,9 +1726,7 @@ void AAptInterface::dateFetchNetworkReply(QNetworkReply* reply)
 	}
 
 	if( reply->error() != QNetworkReply::NoError ) {
-		QString dbg = reply->url().fragment() + QString(": error %1: ").arg(reply->error()) + reply->errorString();
-		qDebug() << dbg;
-		logToFile( dbg );
+		qDebug() << reply->error() << reply->errorString();
 		iDateRequestErrors++;
 	}
 	reply->deleteLater();
@@ -1757,7 +1750,6 @@ void AAptInterface::writeDateCache()
 		f.close();
 	} else {
 		qDebug() << "Warning: failed to write date cache";
-		logToFile(QString("Failed to write date cache"));
 	}
 }
 
@@ -1780,12 +1772,10 @@ void AAptInterface::readDateCache()
 						pkg->setDate( dt );
 					} else {
 						qDebug() << "Warning: Invalid date in date cache";
-						logToFile(QString("Invalid date in date cache"));
 					}
 				}
 			} else {
 				qDebug() << "Warning: error in date cache:" << line;
-				logToFile(QString("Error in date cache"));
 			}
 		}
 		f.close();
