@@ -26,6 +26,8 @@
 #include <QtGui>
 #include <QDBusConnection>
 #include <QDBusInterface>
+#include <phonon/AudioOutput>
+#include <phonon/MediaObject>
 
 #ifdef Q_WS_MAEMO_5
 #include <QtMaemo5>
@@ -43,6 +45,7 @@
 #include "settings.h"
 #include "logview.h"
 #include "rotatingbackground.h"
+#include "dpkginterface.h"
 
 
 MainWindow::MainWindow(QWidget *parent) :
@@ -58,11 +61,19 @@ MainWindow::MainWindow(QWidget *parent) :
 	iWinRepoView->setAptInterface(iAptInterface);
 	iSettings = new Settings(this);
 	iSettings->setAptInterface(iAptInterface);
+	iSettings->setPackageView(iWinPackageView);
 	iWinPackageView->setSettings(iSettings);
 	iAptInterface->setSettings(iSettings);
+	iDpkgInterface = new DpkgInterface(this);
 
 	iWinPackageView->setSortOrder( (PackageView::sortOrder)iSettings->qsettings()->value("default_sort_order",0).toInt() );
 
+	iWinPackageView->setSearchOptions( iSettings->qsettings()->value("search_pkgnames",false).toBool(),
+									   iSettings->qsettings()->value("search_displaynames",true).toBool(),
+									   iSettings->qsettings()->value("search_descshort",false).toBool(),
+									   iSettings->qsettings()->value("search_desclong",false).toBool() );
+
+
 #ifdef Q_WS_MAEMO_5
 	this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	if( !iSettings->qsettings()->value("disable_autorotation",false).toBool() ) {
@@ -72,19 +83,12 @@ MainWindow::MainWindow(QWidget *parent) :
 	}
 #endif
 
-	//iOperation = OpNone;
 	iDimmer = new dimmer(this);
 
-	//iAptInterface->setUpdateDimmer( iWinPackageView->dim() );
-
 	iReposAutoUpdating = false;
 	iUpgradeAutoUpdate = true;
 	iNextOperation = OpNone;
 
-	// clear log on startup
-	QFile logfile(KLogFileName);
-	logfile.remove();
-
 	ui->centralWidget->loadWallpaper();
 
 	QString stylesheet_mainscreen =
@@ -136,6 +140,10 @@ MainWindow::MainWindow(QWidget *parent) :
 	net.call(method,"[ANY]",0);
 	*/
 
+	iMediaObject = new Phonon::MediaObject(this);
+	Phonon::AudioOutput* aout = new Phonon::AudioOutput(Phonon::NotificationCategory, this);
+	Phonon::createPath(iMediaObject, aout);
+
 	resetIdlingTime();
 }
 
@@ -147,6 +155,7 @@ MainWindow::~MainWindow()
 	delete iWinPackageView;
 	delete iWinRepoView;
 	delete iAptInterface;
+	delete iDpkgInterface;
 	delete iDimmer;
 	delete iSettings;
     delete ui;
@@ -219,12 +228,12 @@ void MainWindow::on_btnListInstallable_clicked()
 {
 	//install
 
-	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-15*60) )
-		iAptInterface->setNeedListRefresh(true);
+	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-30*60) )
+		iAptInterface->setNeedRefresh(-1,1,1,1);
 
 	iWinPackageView->setStatFilter( Package::PkgStatNotInstalled );
 
-	if( iAptInterface->needRepoRefresh() ) //&& !iSettings->qsettings()->value("never_auto_update", false).toBool() )
+	if( iAptInterface->needRepoRefresh() )
 		iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetUpdate);
 
 	busyDialog(true, tr("Operation in progress"), tr("Reading package lists"));
@@ -241,12 +250,12 @@ void MainWindow::on_btnUpgrade_clicked()
 {
 	// upgrade
 
-	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-15*60) )
-		iAptInterface->setNeedListRefresh(true);
+	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-30*60) )
+		iAptInterface->setNeedRefresh(-1,1,1,1);
 
 	iWinPackageView->setStatFilter( Package::PkgStatUpgradeable );
 
-	if( iAptInterface->needRepoRefresh() ) //&& !iSettings->qsettings()->value("never_auto_update", false).toBool() )
+	if( iAptInterface->needRepoRefresh() )
 		iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetUpdate);
 
 	busyDialog(true, tr("Operation in progress"), tr("Reading package lists"));
@@ -263,15 +272,14 @@ void MainWindow::on_btnListInstalled_clicked()
 {
 	//remove
 
-	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-15*60) )
-		iAptInterface->setNeedListRefresh(true);
+	if( !iSettings->qsettings()->value("remove_readfull",false).toBool() )
+		iAptInterface->setSkipListAndDates();
+
+	if( iIdlingSince < QDateTime::currentDateTime().addSecs(-30*60) )
+		iAptInterface->setNeedRefresh(-1,-1,1,-1);
 
 	iWinPackageView->setStatFilter( Package::PkgStatInstalled );
 
-	// should not require this on remove?
-	if( iAptInterface->needRepoRefresh() ) //&& !iSettings->qsettings()->value("never_auto_update", false).toBool() )
-		iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetUpdate);
-
 	busyDialog(true, tr("Operation in progress"), tr("Reading package lists"));
 
 	iNextOperation = OpOpenPkgView;
@@ -399,7 +407,7 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 		if( d.exec() ) {
 			iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetInstall);
 
-			if( iSettings->qsettings()->value("enable_autoclean",false).toBool() && inst.count()>0 )
+			if( iSettings->qsettings()->value("enable_autoclean",true).toBool() && inst.count()>0 )
 				iAptInterface->addQueuedOperation(AAptInterface::ModeAptGetClean);
 
 			QString busytext;
@@ -422,10 +430,20 @@ void MainWindow::operationQueueFinished(QList<AAptInterface::interfaceMode> last
 	} else {
 		busyDialog(false);
 		iNextOperation = OpNone;
-		ConfirmDialog d(false, this);
-		QString text = msgs.join("<br>");
-		d.setText(title, text);
-		d.exec();
+
+		if( iSettings->qsettings()->value("sound_notify",false).toBool() )
+		{
+			qDebug() << "playing sound";
+			iMediaObject->setCurrentSource( Phonon::MediaSource(iSettings->qsettings()->value("sound_file","/usr/share/sounds/ui-operation_ready.wav").toString()) );
+			iMediaObject->play();
+		}
+
+		QString text = "<br><b><u>Faster Application Manager</u></b><br>"
+				"<b>"+title+"</b><br>" + msgs.join("<br>") + "<br>";
+
+#ifdef Q_WS_MAEMO_5
+		QMaemo5InformationBox::information(0, text, QMaemo5InformationBox::NoTimeout);
+#endif
 	}
 
 }
@@ -529,3 +547,22 @@ void MainWindow::GdkEventIconThemeReload()
 
 #endif
 }
+
+void MainWindow::on_actionLoad_file_triggered()
+{
+	QStringList files = QFileDialog::getOpenFileNames(this, "Open files", "/", "Files (*.deb *.install)");
+	if( files.count() > 0 ) {
+		QStringList debs = files.filter(QRegExp(".*\\.deb$"));
+		QStringList installs = files.filter(QRegExp(".*\\.install$"));
+		if( debs.count()>0 && installs.count()>0 ) {
+			ConfirmDialog d(false, this);
+			d.setText("Error", "You can't mix different file types in your selection");
+			d.exec();
+			return;
+		}
+		if( debs.count()>0 )
+			iDpkgInterface->loadDebFiles(debs);
+		else if( installs.count()>0 )
+			iAptInterface->loadInstallFiles(installs);
+	}
+}
